@@ -1,13 +1,18 @@
 # Generics ---------------------------------------------------------------
+#nolint start
 #' Get and set slide analyses
 #'
 #' Slides are composed of analyses, which are effectively `CrunchCubes` with some
 #' additional metadata. You can get and set a slide's Analysis Catalog with the
-#' `analyses` method, and access an individual analysis with `analysis`.
+#' `analyses` method, and access an individual analysis with `analysis`. There
+#' are also helpers to get and set the components of the analysis such as `filter()`,
+#' `weight()`, `transforms()`, `displaySettings()` and `vizSpecs()`. You can also
+#' get the `CrunchCube` from an analysis using `cube()`.
 #'
-#' You can get the `CrunchCube` from a slide or analysis with the `cube` method and
-#' from a `CrunchDeck` with `cubes`. Analyses can be changed by assigning a formula
-#' into the `query` function.
+#' For more complex objects like `displaySettings()`, `vizSpecs()` and `transforms()`,
+#' the [API documentation](
+#' https://crunch.io/api/reference/#patch-/datasets/-dataset_id-/decks/-deck_id-/slides/-slide_id-/analyses/-analysis_id-/)
+#' provides more details.
 #'
 #' Advanced users of the API can assign a list to  `analysis<-` to specify settings
 #' on the analyses that are not otherwise available in `rcrunch`. The helpers
@@ -15,9 +20,9 @@
 #' `query` and `query_environment`.
 #'
 #' @param x a `CrunchSlide`, `AnalysisCatalog`, or `Analysis`
-#' @param value for the setter, a query
+#' @param value for the setter, an object to set it
 #' @param query For `formulaToSlideQuery()`, a formula that specifies the query, as in
-#' `newSlide()`
+#' `newSlide()`. See Details of [`crtabs()`] for more information.
 #' @param dataset For `formulaToSlideQuery()`, a `CrunchDataset` that the variables in
 #' `query` refer to.
 #' @param weight For `slideQueryEnv()` a crunch variable to use as a weight or `NULL`
@@ -26,19 +31,39 @@
 #' the slide.
 #' @param ... ignored
 #'
-#' @return an `AnalysisCatalog`, `Analysis`, `Cube`, or `Filter`
 #' @rdname analysis-methods
 #' @export
 #' @examples
 #' \dontrun{
-#' analysis(slide)
-#' cube(slide)
-#' cubes(deck)
-#' query(slide) <- ~ cyl + wt
-#' filter(slide)
+#' # Examples of setting analysis details (in general these setters work on
+#' # the slide, analysis catalog and analysis, but for brevity the examples only
+#' # show on the slide)
+#'
+#' # Change the filter
 #' filter(slide) <- NULL # to remove a filter
 #' filter(slide) <- filters(ds)[["My filter"]]
+#' filter(deck) <- filters(ds)[["My filter"]] # Can set the same filter on a whole deck too
+#'
+#' # Change the weight
+#' weight(slide) <- NULL # to remove
+#' weight(slide) <- ds$weight
+#' weight(deck) <- ds$weight # Can set the same weight on a whole deck too
+#'
+#' # Change the transforms
+#' transforms(slide) <- list(rows_dimension = makeDimTransform(hide = "Neutral"))
+#'
+#' # Change the displaySettings
+#' displaySettings(slide) <- list(vizType = "groupedBarPlot")
+#'
+#' # Change the vizSpecs
+#' # viz_specs can get quite long, see
+#' # https://crunch.io/api/reference/#post-/datasets/-dataset_id-/decks/-deck_id-/slides/
+#' vizSpecs(slide) <- viz_specs
+#'
+#' # Change the query
+#' #' query(slide) <- ~ cyl + wt
 #' }
+#nolint end
 setGeneric("analyses", function(x) standardGeneric("analyses"))
 #' @rdname analysis-methods
 #' @export
@@ -56,19 +81,20 @@ setGeneric("cube", function(x) standardGeneric("cube"))
 #' @export
 setGeneric("cubes", function(x) standardGeneric("cubes"))
 
-#' Get or set a slide's display settings
-#'
-#' A slide's display settings can be modified by assigning a named list
-#' @param x a CrunchSlide, Analysis, or AnalysisCatalog
-#' @param value a named list, for valid settings see [API documentation](
-#' https://crunch.io/api/reference/#get-/datasets/-dataset_id-/decks/-deck_id-/slides/-slide_id-/)
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setGeneric("displaySettings", function(x) standardGeneric("displaySettings"))
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setGeneric("displaySettings<-", function(x, value) standardGeneric("displaySettings<-"))
 
+#' @rdname analysis-methods
+#' @export
+setGeneric("vizSpecs", function(x) standardGeneric("vizSpecs"))
+#' @rdname analysis-methods
+#' @export
+setGeneric("vizSpecs<-", function(x, value) standardGeneric("vizSpecs<-"))
+
 
 # Slide Catalog -----------------------------------------------------------
 
@@ -208,8 +234,8 @@ DEFAULT_DISPLAY_SETTINGS <- list(
 #' Append a new slide to a Crunch Deck
 #'
 #' @param deck A Crunch Deck
-#' @param query A formula definition of a query to be used by the slide. This is
-#' similar to CrunchCube query
+#' @param query A formula definition of a query to be used by the slide. See
+#' Details of [`crtabs()`] for more information about making queries.
 #' @param display_settings (optional) A list of display settings. If omitted,
 #' slide will be a table of column percentages with hypothesis test highlighting
 #' enabled. The most common setting used is `vizType`, which can be:
@@ -220,6 +246,16 @@ DEFAULT_DISPLAY_SETTINGS <- list(
 #' exports show labels on bars or arcs of donuts.
 #' @param title The slide's title
 #' @param subtitle The slide's subtitle
+#' @param filter a `CrunchLogicalExpression`, a crunch `filter` object or
+#' a vector of names of \code{\link{filters}} defined in the dataset (defaults
+#' to `NULL`, using all data).
+#' @param weight A weight variable (defaults to NULL, meaning no weight)
+#' @param viz_specs Another set of options for the display of the slide, see
+#' the [API documentation](
+#' https://crunch.io/api/reference/#post-/datasets/-dataset_id-/decks/-deck_id-/slides/)
+#' for more information.
+#' @param transform A list of slide transformations, usually created using the function
+#' [`makeDimTransform()`].
 #' @param ... Further options to be passed on to the API
 #'
 #' @return CrunchSlide object
@@ -269,7 +305,54 @@ DEFAULT_DISPLAY_SETTINGS <- list(
 #'     subtitle = "2017 Data"
 #' )
 #'
-#' # Can specify advanced options by specifying `analyses` directly
+#' # A Grouped bar plot with slide transformations to hide a category
+#' newSlide(
+#'     main_deck,
+#'     ~ approval + age4,
+#'     title = "Approval by age group",
+#'     display_settings = list(
+#'         vizType = "groupedBarPlot",
+#'         showValueLabels = TRUE
+#'     ),
+#'     transform = list(rows_dimension = makeDimTransform(hide = "Neutral")),
+#'     subtitle = "2017 Data"
+#' )
+#'
+#' # Example of advanced options being set:
+#' # viz_specs can get quite long, see
+#' # https://crunch.io/api/reference/#post-/datasets/-dataset_id-/decks/-deck_id-/slides/
+#' viz_specs <- list(
+#'     default = list(
+#'         format = list(
+#'             decimal_places = list(percentages = 0L, other = 2L),
+#'             show_empty = FALSE
+#'         )
+#'     ),
+#'     table = list(
+#'         measures = c("col_percent", "pairwise_t_test"),
+#'         page_layout = list(
+#'             rows = list(
+#'                 top = list(),
+#'                 bottom = c("base_unweighted", "scale_mean", "significant_columns")
+#'             ),
+#'             measure_layout = "long"
+#'         ),
+#'         pairwise_comparison = list(sig_threshold = c(0.05, 0.01)),
+#'         format = list(pval_colors = FALSE)
+#'     )
+#' )
+#'
+#' newSlide(
+#'     main_deck,
+#'     ~categories(fav_array)+subvariables(fav_array),
+#'     display_settings = list(viz_type = list(value = "table")),
+#'     title = "custom slide",
+#'     filter = filters(ds)[[1]],
+#'     weight = ds$weight,
+#'     viz_specs = viz_specs
+#' )
+#'
+#' # Can also specify `analyses` directly, which allows for very advanced use.
 #' # `formulaToSlideQuery()` and `slideQueryEnv()` help describe the API
 #' newSlide(
 #'     main_deck,
@@ -278,62 +361,58 @@ DEFAULT_DISPLAY_SETTINGS <- list(
 #'         query = formulaToSlideQuery(~categories(fav_array)+subvariables(fav_array), ds),
 #'         query_environment = slideQueryEnv(filter = filters(ds)[[1]]),
 #'         display_settings = list(viz_type = list(value = "table")),
-#'         viz_specs =  list(
-#'             default = list(
-#'                 format = list(
-#'                     decimal_places = list(percentages = 0L, other = 2L),
-#'                     show_empty = FALSE
-#'                 )
-#'              ),
-#'              table = list(
-#'              measures = c("col_percent", "pairwise_t_test"),
-#'              page_layout = list(
-#'                  rows = list(
-#'                      top = list(),
-#'                      bottom = c("base_unweighted", "scale_mean", "significant_columns")
-#'                  ),
-#'                  measure_layout = "long"
-#'              ),
-#'              pairwise_comparison = list(sig_threshold = c(0.05, 0.01)),
-#'              format = list(pval_colors = FALSE)
-#'             )
-#'         )
+#'         viz_specs = viz_specs
 #'     ))
 #' )
 #' }
-newSlide <- function(deck,
-                     query = NULL,
-                     display_settings = list(),
-                     title = "",
-                     subtitle = "",
-                     ...) {
+newSlide <- function(
+    deck,
+    query = NULL,
+    display_settings = list(),
+    title = "",
+    subtitle = "",
+    filter = NULL,
+    weight = NULL,
+    viz_specs = NULL,
+    transform = NULL,
+    ...
+) {
     stopifnot(inherits(query, "formula") || is.null(query))
     settings <- modifyList(DEFAULT_DISPLAY_SETTINGS, display_settings)
     settings <- wrapDisplaySettings(settings)
 
     ds <- loadDataset(datasetReference(deck))
+    filter <- standardize_tabbook_filter(ds, filter)
 
     payload <- list(title = title, subtitle = subtitle, ...)
-    if ("analyses" %in% names(payload) && !is.null(query)) {
-        halt("Cannot specify both a `query` and `analyses` for `newSlide()`")
-    }
-    if (!"analyses" %in% names(payload) && is.null(query)) {
-        halt("Must specify either a `query` or `analyses` for `newSlide()`")
-    }
-    if (!"analyses" %in% names(payload) && length(display_settings) != 0) {
-        warning(
-            "`display_settings` are ignored if `analyses` are defined directly for `newSlide()`"
-        )
+    check_newslide_args(
+        query, display_settings, payload, filter, weight, viz_specs, transform
+    )
+
+    if (any(dimTransformNeedsPrep(transform))) {
+        transform <- prepareDimTransforms(transform, query, ds) #nolint
     }
 
     if (!is.null(query)) {
-        # Technically multiple analyses per slide are allowed (for profiles), but this
-        # isn't supported in the R package, and if someone really wants it, they could
-        # form the analyses object themselves
-        payload[["analyses"]] <- list(list(
+        analysis <- list(
             query = formulaToCubeQuery(query, ds),
             display_settings = settings
-        ))
+        )
+
+        query_environment <- list()
+        if (!is.null(filter)) query_environment$filter <- filter
+        if (!is.null(weight)) {
+            query_environment$weight <- self(weight)
+            # Also add to the query to match webapp behavior
+            analysis$query$weight <- self(weight)
+        }
+        if (length(query_environment) > 0) analysis$query_environment <- query_environment
+        if (!is.null(viz_specs)) {
+            analysis$viz_specs <- viz_specs
+        }
+        if (!is.null(transform)) analysis$transform <- transform
+
+        payload[["analyses"]] <- list(analysis)
     }
 
     payload <- wrapEntity(body = payload)
@@ -341,6 +420,33 @@ newSlide <- function(deck,
     return(CrunchSlide(crGET(url)))
 }
 
+
+#nolint start
+check_newslide_args <- function(
+    query, display_settings, payload, filter, weight, viz_specs, transform
+) {
+    has_analyses <- "analyses" %in% names(payload)
+    has_any_analysis_objects <- length(display_settings) != 0 ||
+        !is.null(filter) ||
+        !is.null(weight) ||
+        !is.null(viz_specs) ||
+        !is.null(transform)
+
+    if (has_analyses && !is.null(query)) {
+        halt("Cannot specify both a `query` and `analyses` for `newSlide()`")
+    }
+    if (!has_analyses && is.null(query)) {
+        halt("Must specify either a `query` or `analyses` for `newSlide()`")
+    }
+    if (has_analyses && has_any_analysis_objects) {
+        warning(paste0(
+            "`display_settings`, `filter`, `weight`, `viz_specs` and `transform` are ",
+            "ignored if `analyses` are defined directly for `newSlide()`"
+        ))
+    }
+}
+#nolint end
+
 #' @rdname crunch-extract
 #' @export
 setMethod("[[", "CrunchSlide", function(x, i, ...) {
@@ -447,10 +553,10 @@ setMethod("cubes", "CrunchSlide", function(x) cubes(analyses(x)))
 #' @rdname analysis-methods
 #' @export
 setMethod("cube", "CrunchSlide", function(x) cube(analyses(x)[[1]]))
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setMethod("displaySettings", "CrunchSlide", function(x) displaySettings(analyses(x)))
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setMethod("displaySettings<-", "CrunchSlide", function(x, value) {
     an_cat <- analyses(x)
@@ -458,6 +564,17 @@ setMethod("displaySettings<-", "CrunchSlide", function(x, value) {
     return(invisible(x))
 })
 
+#' @rdname analysis-methods
+#' @export
+setMethod("vizSpecs", "CrunchSlide", function(x) vizSpecs(analyses(x)))
+#' @rdname analysis-methods
+#' @export
+setMethod("vizSpecs<-", "CrunchSlide", function(x, value) {
+    an_cat <- analyses(x)
+    vizSpecs(an_cat) <- value
+    return(invisible(x))
+})
+
 # AnalysisCatalog --------------------------------------------------------------
 
 setMethod("initialize", "AnalysisCatalog", function(.Object, ...) {
@@ -507,7 +624,7 @@ setMethod(
         # and update fixtures
         payload <- value@body[
             na.omit(match(
-                c("query", "display_settings", "query_environment", "viz_specs", "transforms"),
+                c("query", "display_settings", "query_environment", "viz_specs", "transform"),
                 names(value@body)
             ))
         ]
@@ -549,7 +666,7 @@ setMethod("cubes", "AnalysisCatalog", function(x) {
     lapply(seq_along(x@index), function(i) cube(x[[i]]))
 })
 
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setMethod("displaySettings", "AnalysisCatalog", function(x) {
     settings_list <- lapply(seq_along(x), function(i) {
@@ -561,13 +678,32 @@ setMethod("displaySettings", "AnalysisCatalog", function(x) {
         return(settings_list)
     }
 })
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setMethod("displaySettings<-", c("AnalysisCatalog", "list"), function(x, value) {
     analyses <- lapply(seq_along(x), function(i) x[[i]])
     lapply(analyses, function(x) displaySettings(x) <- value)
 })
 
+#' @rdname analysis-methods
+#' @export
+setMethod("vizSpecs", "AnalysisCatalog", function(x) {
+    settings_list <- lapply(seq_along(x), function(i) {
+        vizSpecs(x[[i]])
+    })
+    if (length(settings_list) == 1) {
+        return(settings_list[[1]])
+    } else {
+        return(settings_list)
+    }
+})
+#' @rdname analysis-methods
+#' @export
+setMethod("vizSpecs<-", c("AnalysisCatalog", "list"), function(x, value) {
+    analyses <- lapply(seq_along(x), function(i) x[[i]])
+    lapply(analyses, function(x) vizSpecs(x) <- value)
+})
+
 
 # Analysis ----------------------------------------------------------------
 #' @rdname analysis-methods
@@ -589,18 +725,36 @@ formulaToSlideQuery <- function(query, dataset) {
 #' @rdname analysis-methods
 #' @export
 setMethod("cube", "Analysis", function(x) {
+    # Always use the weight from the query_environment (even if missing in qe, we want to
+    # override with no weight in this case)
+    cube_query <- x@body$query
+    cube_query$weight <- NULL
+    # Actually want weight=NULL to override the default dataset weight
+    cube_query <- c(cube_query, list(weight = x@body$query_environment$weight))
+
+    http_query <- list(query = toJSON(cube_query, for_query_string = TRUE))
+
+    # Don't pass filter=NULL because API's probably grumpy about that. Also, rather than pass a
+    # list of filters if there are multiple, the API expects multiple `filter=` URL query
+    # parameters
+    qe_filters <- x@body$query_environment$filter
+    if (length(qe_filters) > 0) {
+        qe_filters <- lapply(qe_filters, function(filt) toJSON(filt, for_query_string = TRUE))
+        names(qe_filters) <- rep("filter", length(qe_filters))
+        http_query <- c(http_query, qe_filters)
+    }
+
     CrunchCube(crGET(
         cubeURL(x),
-        query = list(query = toJSON(x@body$query)),
-        filter = toJSON(x@body$query_environment$filter)
+        query = http_query
     ))
 })
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setMethod("displaySettings", "Analysis", function(x) {
     lapply(x@body$display_settings, function(x) x$value)
 })
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setMethod("displaySettings<-", "Analysis", function(x, value) {
     settings <- modifyList(displaySettings(x), value)
@@ -610,6 +764,18 @@ setMethod("displaySettings<-", "Analysis", function(x, value) {
     crPATCH(self(x), body = toJSON(payload))
     invisible(refresh(x))
 })
+#' @rdname analysis-methods
+#' @export
+setMethod("vizSpecs", "Analysis", function(x) {
+    x@body$viz_specs
+})
+#' @rdname analysis-methods
+#' @export
+setMethod("vizSpecs<-", "Analysis", function(x, value) {
+    payload <- wrapEntity(body = list(viz_specs = value))
+    crPATCH(self(x), body = toJSON(payload))
+    invisible(refresh(x))
+})
 
 # This processes a names list of display setting values to the form that is
 # required by the API.
@@ -628,7 +794,17 @@ setMethod("filter", "Analysis", function(x, ...) {
         return(CrunchFilter(crGET(filt[[1]]$filter)))
     } else {
         # an adhoc filter
-        adhoc_expr <- CrunchExpr(expression = fixAdhocFilterExpression(filt[[1]]))
+        ds_url <- datasetReference(x)
+        adhoc_expr <- CrunchLogicalExpr(
+            expression = idsToURLs(
+                # 02/2021: Not sure if this is still needed anymore, server doesn't
+                # currently seem to be sending the `dataset` attributes this takes out.
+                # But mocks require it (/4/decks/8ad8/slides/72e8/analysies/52fb.json)
+                fixAdhocFilterExpression(filt[[1]]),
+                paste0(ds_url, "/variables/")
+            ),
+            dataset_url = ds_url
+        )
         return(adhoc_expr)
     }
 })
@@ -656,27 +832,21 @@ setMethod("filter<-", "CrunchSlide", function(x, value) {
 #' @rdname analysis-methods
 #' @export
 setMethod("filter<-", c("Analysis", "CrunchLogicalExpr"), function(x, value) {
-    halt("Setting adhoc filters on decks is unsupported")
-    # the following _should_ work, however query_environment filters must include
-    # dataset references (which our expression to ZCL converter does not support)
-    # This should be fixed in https://www.pivotaltracker.com/story/show/157399444
-    # once query_environment is changed to work like every other expression, the
-    # following should just work:
-    # return(set_query_env_slot(x, filter = list(value@expression)))
+    return(set_analysis_filter_or_weight(x, filter = list(value@expression)))
 })
 
 #' @rdname analysis-methods
 #' @export
 setMethod("filter<-", c("Analysis", "CrunchFilter"), function(x, value) {
     # crPATCH(self(x), body = toJSON(frmt))
-    return(set_query_env_slot(x, filter = list(self(value))))
+    return(set_analysis_filter_or_weight(x, filter = list(self(value))))
 })
 
 #' @rdname analysis-methods
 #' @export
 setMethod("filter<-", c("Analysis", "NULL"), function(x, value) {
     # crPATCH(self(x), body = toJSON(frmt))
-    return(set_query_env_slot(x, filter = list()))
+    return(set_analysis_filter_or_weight(x, filter = list()))
 })
 
 #' @rdname analysis-methods
@@ -687,15 +857,13 @@ slideQueryEnv <- function(weight, filter) {
     }
     out <- list()
     if (!missing(weight)) {
-        out$weight <- if (is.null(weight)) list() else list(self(weight))
+        out$weight <- if (is.null(weight)) list() else self(weight)
     }
     if (!missing(filter)) {
         if (is.null(filter)) {
             out$filter <- list()
         } else if (is.CrunchExpr(filter)) {
-            # Reasoning explained in `setMethod("filter<-", c("Analysis", "CrunchLogicalExpr")`
-            halt("ad-hoc filters not supported for slides")
-            # out$filter <- list(filter@expression)
+            out$filter <- list(filter@expression)
         } else {
             out$filter <- list(self(filter))
         }
@@ -703,7 +871,7 @@ slideQueryEnv <- function(weight, filter) {
     out
 }
 
-#' @rdname display-settings
+#' @rdname analysis-methods
 #' @export
 setMethod("cubes", "CrunchDeck", function(x) {
     out <- lapply(seq_len(length(x)), function(i) {
@@ -721,14 +889,14 @@ setMethod("cubes", "CrunchDeck", function(x) {
 })
 
 
-#' @rdname weight
+#' @rdname analysis-methods
 #' @export
 setMethod("weight", "CrunchSlide", function(x) {
     analysis <- analyses(x)[[1]]
     return(weight(analysis))
 })
 
-#' @rdname weight
+#' @rdname analysis-methods
 #' @export
 setMethod("weight<-", c("CrunchSlide", "ANY"), function(x, value) {
     # check that there is only on analysis?
@@ -737,7 +905,7 @@ setMethod("weight<-", c("CrunchSlide", "ANY"), function(x, value) {
     return(invisible(x))
 })
 
-#' @rdname weight
+#' @rdname analysis-methods
 #' @export
 setMethod("weight", "Analysis", function(x) {
     wt <- x@body$query_environment$weight
@@ -747,8 +915,11 @@ setMethod("weight", "Analysis", function(x) {
     full_ds <- loadDataset(datasetReference(VariableEntity(x)))
     wt_pos <- which(urls(allVariables(full_ds)) == wt)
     filt <- filter(x)
-    if (!is.null(filt)) {
-        filt <- CrunchLogicalExpr(expression = filt@body[["expression"]])
+    if (inherits(filt, "CrunchFilter")) {
+        filt <- CrunchLogicalExpr(
+            dataset_url = self(full_ds),
+            expression = filt@body[["expression"]]
+        )
     }
     CrunchVariable(allVariables(full_ds)[[wt_pos]], filter = filt)
 })
@@ -759,24 +930,32 @@ setMethod("weight<-", c("Analysis", "CrunchVariable"), function(x, value) {
     if (!is.weightVariable(value)) halt(paste0(
         "Variable '", alias(value), "' is not a weightVariable"
     ))
-    return(set_query_env_slot(x, weight = self(value)))
+    return(set_analysis_filter_or_weight(x, weight = self(value)))
 })
 
 #' @rdname weight
 #' @export
 setMethod("weight<-", c("Analysis", "NULL"), function(x, value) {
-    return(set_query_env_slot(x, weight = NULL))
+    return(set_analysis_filter_or_weight(x, weight = NULL))
 })
 
 # TODO: setMethod("weight<-", c("Analysis", "CrunchVariable") method to use alias?
 
 # Want to update filter/weight components separately so that we don't
 # remove something accidentally.
-set_query_env_slot <- function(x, filter, weight) {
+set_analysis_filter_or_weight <- function(x, filter, weight) {
     query_env <- slot(x, "body")[["query_environment"]]
     # The single "[" <- list() notation allows NULLs in weight rather than just removing weight
     if (!missing(filter)) query_env["filter"] <- list(filter)
     if (!missing(weight)) query_env["weight"] <- list(weight)
 
-    setEntitySlot(x, "query_environment", query_env)
+    # Also need to set weight in the query to match webapp's behavior
+    if (!missing(weight)) {
+        query <- slot(x, "body")[["query"]]
+        query$weight <- weight
+        setMultiEntitySlots(x, query_environment = query_env, query = query)
+    } else { # But if only updating filter, then leave query alone
+        setEntitySlot(x, "query_environment", query_env)
+    }
+
 }
