@@ -5,7 +5,7 @@ set.seed(666)
 
 skip_on_jenkins <- function(...) {
     if (nchar(Sys.getenv("JENKINS_HOME"))) {
-        skip(...)
+        skip(...) # nolint
     }
 }
 
@@ -52,11 +52,6 @@ newDatasetFromFixture <- function(filename) {
     )))
 }
 
-releaseAndReload <- function(dataset) {
-    .releaseDataset(dataset)
-    return(refresh(dataset))
-}
-
 ## Data frames to make datasets with
 df <- data.frame(
     v1 = c(rep(NA_real_, 5), rnorm(15)),
