@@ -58,7 +58,7 @@ mr.ids <- data.frame(
 )
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
     test_that("setup", {
         expect_identical(dim(ds), c(nrow(ds), ncol(ds)))
         expect_identical(dim(ds), c(25L, 7L))
@@ -132,7 +132,8 @@ with_mock_crunch({
     })
 
     test_that("as.data.frame when a variable has an apostrophe in its alias", {
-        t2 <- ds
+        t2 <- forceVariableCatalog(ds)
+
         t2@variables@index[[2]]$alias <- "Quote 'unquote' alias"
         expect_is(as.data.frame(t2), "CrunchDataFrame")
     })
@@ -146,7 +147,7 @@ with_mock_crunch({
     })
 
     test_that("as.data.frame() works with hidden variables", {
-        new_ds <- loadDataset("test ds")
+        new_ds <- cachedLoadDataset("test ds")
         new_ds$gender@tuple[["discarded"]] <- TRUE
         new_ds_df <- as.data.frame(new_ds, include.hidden = TRUE)
         expect_equal(
@@ -321,6 +322,8 @@ with_test_authentication({
     })
 
     v2 <- ds$v2
+    # Force variable catalog so that it'll get stale
+    ds <- forceVariableCatalog(ds)
     with_consent(delete(v2))
     test_that("CrunchDataFrame lazily fetches columns", {
         expect_true("v2" %in% names(ds)) ## ds is stale
@@ -329,6 +332,7 @@ with_test_authentication({
         expect_error(as.data.frame(ds, force = TRUE))
     })
 
+    ds <- forceVariableCatalog(ds)
     uncached({
         with_mock(`crunch::.crunchPageSize` = function(x) 5L, {
             with(temp.option(httpcache.log = ""), {
