@@ -1,7 +1,7 @@
 context("Deriving array variables")
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
     test_that("deriveArray works with MR", {
         expect_POST(
             ds$derived_mr <- deriveArray(list(ds$gender),
@@ -12,8 +12,8 @@ with_mock_crunch({
             "https://app.crunch.io/api/datasets/1/variables/",
             '{"derivation":{"function":"select_categories","args":',
             '[{"function":"array","args":[{"function":"make_frame","args":',
-            '[{"map":{"1":{"variable":"https://app.crunch.io/api/datasets',
-            '/1/variables/gender/"}}},{"value":["1"]}]}],"kwargs":{"numeric":{"value":false}}},', # nolint
+            '[{"map":{"0001":{"variable":"https://app.crunch.io/api/datasets',
+            '/1/variables/gender/"}}},{"value":["0001"]}]}],"kwargs":{"numeric":{"value":false}}},', # nolint
             '{"value":["Female"]}]},"name":"derivedMR","alias":"derived_mr"}'
         )
     })
