@@ -108,7 +108,7 @@ test_that("Subtotal/Heading setters", {
 })
 
 with_mock_crunch({
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
 
     test_that("subtotals retrieves the subtotals and headings Insertions", {
         expect_equivalent(
